/*
 *     This file is part of the Action Word Workspace plugin for Squash TM (henix-tm-workspace-action-word) project.
 *     Copyright (C) 2020 - 2021 Henix, henix.fr - All Rights Reserved
 *
 *     Unauthorized copying of this file, via any medium is strictly prohibited
 *     Proprietary and confidential
 *
 * 	 (C)Henix. Tous droits réservés.
 *
 * 	Avertissement : ce programme est protégé par la loi relative au droit d'auteur et par les conventions internationales. Toute reproduction ou distribution partielle ou totale du logiciel, par quelque moyen que ce soit, est strictement interdite.
 */
define(['squash.translator',
        'tree',
        './action-word-treemenu',
        './init-actions',
        'squash/squash.tree-page-resizer',
        'app/ws/squashtm.toggleworkspace',
        './popups/init-all'
    ],
    function (translator, tree, treemenu, actions, resizer, ToggleWorkspace, popups) {
        "use strict";

        function resizeLeftPanel() {
            $("#tree-panel-left").css('width', localStorage.getItem("leftWidth"));
            var pos = parseInt(localStorage.getItem("leftWidth")) + 10;
            $("#contextual-content").css('left', pos + "px");
        }

        function initResizer() {
            var conf = {
                leftSelector: "#tree-panel-left",
                rightSelector: "#contextual-content"
            };
            resizer.init(conf);
        }

        function initTabbedPane() {
            $("#tabbed-pane").tabs();
        }

        function initI18n() {
            translator.load({
                "date-format": "squashtm.dateformat",
                "label-never": "label.lower.Never"
            });
        }

        function init(settings) {
            initI18n();
            resizeLeftPanel();
            initResizer();
            initTabbedPane();
            ToggleWorkspace.init(settings.toggleWS);
            tree.initWorkspaceTree(settings.tree);
            treemenu.init(settings.treemenu);
            popups.init();
            actions.init();
        }

        return {
            init: init
        };

    });
