/*
 *     This file is part of the Action Word Workspace plugin for Squash TM (henix-tm-workspace-action-word) project.
 *     Copyright (C) 2020 - 2021 Henix, henix.fr - All Rights Reserved
 *
 *     Unauthorized copying of this file, via any medium is strictly prohibited
 *     Proprietary and confidential
 *
 * 	 (C)Henix. Tous droits réservés.
 *
 * 	Avertissement : ce programme est protégé par la loi relative au droit d'auteur et par les conventions internationales. Toute reproduction ou distribution partielle ou totale du logiciel, par quelque moyen que ce soit, est strictement interdite.
 */
define(['jquery', 'backbone', 'tree', "workspace.event-bus", "underscore", "squash.configmanager", "squash.basicwidgets", "./parameter-table", "./using-test-case-table", "./implementation-table", "jquery.squash.jeditable"],
    function ($, Backbone, jsTree, eventBus, _, confManager, basic, ParameterTable, UsingTestCaseTable, ImplementationTable) {

        var View = Backbone.View.extend({
            el: "#contextual-content-wrapper",

            initialize : function(settings) {
                this.settings = settings;
                this.tree = jsTree.get();
                basic.init();
                if(settings.actionWord.writable) {
                    this.initEditables(settings.actionWord.id);
                }
                this.initParameterTable(settings);
                this.initUsingTestCaseTable(settings);
                this.initImplementationTable(settings);
                this.listenTo(this.table, "actionword.parameter.name.update", this.refreshName);
                this.listenTo(this.table, "actionword.parameter.default-value.update", this.refreshName);
            },
            initEditables: function(actionWordId) {
                var richEditableSettings = confManager.getJeditableCkeditor();
                richEditableSettings.url = squashtm.app.contextRoot + "action-word/" + actionWordId + "/description"
                $('#action-word-description')
                    .richEditable(richEditableSettings)
                    .addClass("editable");
            },

            initParameterTable: function(settings) {
                this.table = new ParameterTable(settings);
            },

            initUsingTestCaseTable: function(settings) {
                new UsingTestCaseTable(settings);
            },

            initImplementationTable: function(settings) {
                new ImplementationTable(settings);
            },

            /**
             * Refresh the Title of the ActionWord and its Name in the Tree.
             */
            refreshName: function() {
                var self = this;
                $.ajax({
                    method: 'GET',
                    url: squashtm.app.contextRoot + 'action-word/' + self.settings.actionWord.id + '/title'
                }).then(function(newName) {
                    // the title
                    $('#action-word-name').html(newName);
                    // the name in the tree
                    var node = self.tree.jstree('get_selected');
                    eventBus.trigger("node.rename", {
                        identity: node.getIdentity(),
                        newName: newName
                    });
                });
            }
        });
        return View;
    });
